@@ -20,10 +20,10 @@ import time
 import torchaudio
 import json
 import re
+from speechbrain.utils.torch_audio_backend import get_torchaudio_backend
 
-torchaudio.set_audio_backend(
-    "sox_io"
-)  # switch to 'soundfile' for windows machines.
+torchaudio_backend = get_torchaudio_backend()
+torchaudio.set_audio_backend(torchaudio_backend)
 logger = logging.getLogger(__name__)
 
 
